@@ -1,7 +1,8 @@
 """Module providing tools to make a sound."""
 from support_developer import support_luca
 from .ringbell import RingBell
+from ._auto_ringbell import auto_ringbell
 
 support_luca("ringbell")
 
-__all__ = ["RingBell"]
\ No newline at end of file
+__all__ = ["RingBell", "auto_ringbell"]
\ No newline at end of file
